gibbs_fsw_binomial: Runs a gibbs sampler chain with a Binomial prior on N to...

Description Usage Arguments Value

View source: R/gibbs_fsw_binomial.R

Description

Runs a gibbs chain with a binomial prior with listing data input

Usage

1
2
gibbs_fsw_binomial(seed, N = 10000, atune = 0.25, btune = 1,
  inclusionProbPriors, constraint, gibbs.list, parnames)

Arguments

seed

a seed

N

number of iterations for the gibbs sampler. Default 10,000

atune

Tuning parameter for the metropolis-hastings update of hyperparameters on phis

btune

Other tuning parameter for the metropolis-hastings update

inclusionProbPriors

priors for the inclusion probabilities of participating in each listing. should be present in a configureation file.

constraint

Value that represents the lower bound "known" number of flas participants in Mbabane

gibbs.list

list containing all the location listing data

parnames

vector containing parameter names to be estimated

x

log of a.phi/(a.phi+ b.phi)

y

log of (a.phi +b.phi)

phivec

vector of current values of phi

Value

a numeric matrix


andrewpita/gibbsCapRecap documentation built on May 22, 2019, 5:08 p.m.